@@ -9,8 +9,12 @@ use crate::card::Card;
 /// A scores struct which serde can deal with to
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct Scores<'a> {
+    #[serde(default)]
     pub scores: Vec<(Cow<'a, Card>, usize)>,
+    #[serde(default)]
     pub dues: Vec<(Cow<'a, Card>, DateTime<Utc>)>,
+    #[serde(default)]
+    pub circulating: Vec<Cow<'a, Card>>,
 }
 
 impl<'a> From<&'a App> for Scores<'a> {
@@ -42,6 +46,15 @@ impl<'a> From<&'a App> for Scores<'a> {
 
                 dues
             },
+            circulating: {
+                let mut circulating = Vec::new();
+                for card in app.circulating() {
+                    if let Some(card) = app.cards().get(*card) {
+                        circulating.push(Cow::Borrowed(card))
+                    }
+                }
+                circulating
+            },
         }
     }
 }
